@@ -11,8 +11,8 @@ package Dist::Zilla::Plugin::ContributorsFromGit;
 BEGIN {
   $Dist::Zilla::Plugin::ContributorsFromGit::AUTHORITY = 'cpan:RSRCHBOY';
 }
-# git description: 0.011-7-g11b50fe
-$Dist::Zilla::Plugin::ContributorsFromGit::VERSION = '0.012';
+# git description: 0.013-2-g82086ac
+$Dist::Zilla::Plugin::ContributorsFromGit::VERSION = '0.014';
 
 # ABSTRACT: Populate your 'CONTRIBUTORS' POD from the list of git authors
 
@@ -51,7 +51,7 @@ has _contributor_list => (
         my @contributors = uniq
             map  { $self->_contributor_emails->{$_} // $_ }
             grep { $_ ne 'Your Name <you@example.com>'   }
-            grep { @authors->none eq $_                  }
+            grep { [ map { lc } @authors ]->none eq lc   }
             map  { decode_utf8($_)                       }
             map  { chomp; s/^\s*\d+\s*//; $_             }
             `git shortlog -s -e`
@@ -143,7 +143,7 @@ sub before_build {
     };
 
     $_append->('Contributors.contributors' => $self->_contributor_list->flatten);
-    $_append->('StopWords.include'         => $self->_stopwords->flatten);
+    $_append->('-StopWords.include'        => $self->_stopwords->flatten);
 
     ### $config
     return;
@@ -164,8 +164,10 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl David Golden Graham Knop Randy Stauner Tatsuhiko Miyagawa zilla
-BeforeBuild metacpan shortlog committer mailmap
+=for :stopwords Chris Weyl Brendan Tatsuhiko Miyagawa Byrd David Golden Graham Knop Mike
+Greb Randy Stauner zilla BeforeBuild metacpan shortlog committer mailmap
+
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
 =head1 NAME
 
@@ -173,7 +175,7 @@ Dist::Zilla::Plugin::ContributorsFromGit - Populate your 'CONTRIBUTORS' POD from
 
 =head1 VERSION
 
-This document describes version 0.012 of Dist::Zilla::Plugin::ContributorsFromGit - released April 17, 2014 as part of Dist-Zilla-Plugin-ContributorsFromGit.
+This document describes version 0.014 of Dist::Zilla::Plugin::ContributorsFromGit - released July 05, 2014 as part of Dist-Zilla-Plugin-ContributorsFromGit.
 
 =head1 SYNOPSIS
 
@@ -218,6 +220,13 @@ If you have duplicate contributors because of differences in committer name
 or email you can use a C<.mailmap> file to canonicalize contributor names
 and emails.  See L<git help shortlog|git-shortlog(1)> for details.
 
+=head2 Pod::Weaver::Section::Contributors is OPTIONAL
+
+Note that using the L<Pod::Weaver::Section::Contributors> section is in no way
+mandated or necessitated by this package; if you wish to use it you must
+include the Contributors section in your L<Pod::Weaver> configuration in the
+traditional fashion.
+
 =for Pod::Coverage before_build metadata
 
 =head1 METACPAN CONTRIBUTOR MATCHING
@@ -266,6 +275,10 @@ L<Pod::Weaver::Section::Contributors>
 
 L<Dist::Zilla::Stash::PodWeaver>
 
+=item *
+
+L<http://www.dagolden.com/index.php/1921/how-im-using-distzilla-to-give-credit-to-contributors/>
+
 =back
 
 =head1 SOURCE
@@ -286,12 +299,35 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
+=head2 I'm a material boy in a material world
+
+=begin html
+
+<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
+<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2FDist-Zilla-Plugin-ContributorsFromGit&title=RsrchBoy's%20CPAN%20Dist-Zilla-Plugin-ContributorsFromGit&tags=%22RsrchBoy's%20Dist-Zilla-Plugin-ContributorsFromGit%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
+
+=end html
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you if you feel like it ;)
+
+L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2FDist-Zilla-Plugin-ContributorsFromGit&title=RsrchBoy's%20CPAN%20Dist-Zilla-Plugin-ContributorsFromGit&tags=%22RsrchBoy's%20Dist-Zilla-Plugin-ContributorsFromGit%20in%20the%20CPAN%22>,
+L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+
 =head1 CONTRIBUTORS
 
 =over 4
 
 =item *
 
+Brendan Byrd <Perl@ResonatorSoft.org>
+
+=item *
+
 David Golden <dagolden@cpan.org>
 
 =item *
@@ -300,6 +336,10 @@ Graham Knop <haarg@haarg.org>
 
 =item *
 
+Mike Greb <mikegrb@cpan.org>
+
+=item *
+
 Randy Stauner <randy@magnificent-tears.com>
 
 =item *
